import setuptools
long_description = ""
with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="junopass-py",
    version="1.0.1",
    author="Felix Cheruiyot",
    author_email="felix@junopass.com",
    description="JunoPass support for Python.JunoPass provides a secure 2FA and Passwordless authentication.",
    long_description=long_description,
    url="https://github.com/junopass/junopass-py",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Development Status :: 4 - Beta", 
        "Intended Audience :: Developers", 
        "Topic :: Security", 
        "License :: OSI Approved :: MIT License",
    ],
    python_requires='>=3.6',
)
